@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-util-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution/evolution-3.18.3-1.i686/src/evolution-3.18.3/e-util/e-util-enums.h" */
-#include "/usr/src/ports/evolution/evolution-3.18.3-1.i686/src/evolution-3.18.3/e-util/e-util-enums.h"
+/* enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/e-util/e-util-enums.h" */
+#include "/usr/src/ports/evolution/evolution-3.18.5.2-1.x86_64/src/evolution-3.18.5.2/e-util/e-util-enums.h"
 
 GType
 e_activity_state_get_type (void)
