@@ -2,8 +2,8 @@
 /* Generated data (by glib-mkenums) */
 
 #include "e-mail-enumtypes.h"
-/* enumerations from "/usr/src/ports/evolution/evolution-3.18.3-1.i686/src/evolution-3.18.3/mail/e-mail-enums.h" */
-#include "/usr/src/ports/evolution/evolution-3.18.3-1.i686/src/evolution-3.18.3/mail/e-mail-enums.h"
+/* enumerations from "/usr/src/ports/evolution/evolution-3.18.5.2-1.i686/src/evolution-3.18.5.2/mail/e-mail-enums.h" */
+#include "/usr/src/ports/evolution/evolution-3.18.5.2-1.i686/src/evolution-3.18.5.2/mail/e-mail-enums.h"
 
 GType
 e_mail_forward_style_get_type (void)
